package App::TimeTracker::Schema;

use strict;
use warnings;

use base 'DBIx::Class::Schema';

__PACKAGE__->load_classes;


# Created by DBIx::Class::Schema::Loader v0.04002 @ 2008-01-18 19:30:24
# DO NOT MODIFY THIS OR ANYTHING ABOVE! md5sum:fd1+BkLPaigh/crh1tRAYA


# You can replace this text with custom content, and it will be preserved on regeneration
1;

__END__

=pod

=head1 NAME

App::TimeTracker::Schema

=head1 DESCRIPTION

DBIx::Class Schema

=cut

